import { Server } from 'socket.io'
import { TSocket } from '../../utilities/Types'
import ZoneManager from '../../managers/ZoneManager'
import prisma from '../../utilities/Prisma'

type SocketResponseT = {
  position_x: number
  position_y: number
}

export default function (socket: TSocket, io: Server) {
  socket.on('character:move', async (data: SocketResponseT) => {
    try {
      console.log('character:move requested', data)

      if (!socket.character) {
        console.log('character:move error', 'Character not found')
        return
      }

      socket.character.position_x = data.position_x
      socket.character.position_y = data.position_y

      await prisma.character.update({
        where: {
          id: socket.character.id
        },
        data: {
          position_x: data.position_x,
          position_y: data.position_y
        }
      })

      ZoneManager.updateCharacterInZone(socket.character.zoneId, socket.character)
      console.log(socket.character)

      io.in(socket.character.zoneId.toString()).emit('character:moved', socket.character)
    } catch (error: any) {
      console.log('character:move error', error)
    }
  })
}
