import { Server } from 'socket.io'
import { TSocket } from '../../../utilities/Types'
import prisma from '../../../utilities/Prisma'

type Payload = {
  id: string
  name: string
  origin_x: number
  origin_y: number
  frameSpeed: number
  frameWidth: number
  frameHeight: number
  isLooping: boolean
}

/**
 * Handle game master sprite update event
 * @param socket
 * @param io
 */
export default function (socket: TSocket, io: Server) {
  socket.on('gm:sprite:update', async (data: Payload, callback: (success: boolean) => void) => {
    if (socket.character?.role !== 'gm') {
      return
    }

    try {
      const sprite = await prisma.sprite.update({
        where: {
          id: data.id
        },
        data: {
          name: data.name,
          origin_x: data.origin_x,
          origin_y: data.origin_y,
          frameSpeed: data.frameSpeed,
          frameWidth: data.frameWidth,
          frameHeight: data.frameHeight,
          isLooping: data.isLooping
        }
      })

      callback(true)
    } catch (error) {
      console.error(error)
      callback(false)
    }
  })
}
